// java wrapper for vtkStructuredPointsCollection object
//

package vtk;
import vtk.*;

public class vtkStructuredPointsCollection extends vtkCollection
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void AddItem_2(vtkStructuredPoints id0);
  public void AddItem(vtkStructuredPoints id0)
    { AddItem_2(id0); }

  private native long GetNextItem_3();
  public vtkStructuredPoints GetNextItem() {
    long temp = GetNextItem_3();

    if (temp == 0) return null;
    return (vtkStructuredPoints)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  public vtkStructuredPointsCollection() { super(); }

  public vtkStructuredPointsCollection(long id) { super(id); }
  public native long   VTKInit();

}
